@@ -3,5 +3,5 @@ Overview:
     String process module, include some useful utilities for string.
 """
 from .plural import *
-from .template import env_template
-from .trunc import truncate
+from .template import *
+from .trunc import *
